.. _traversal:

Traversal
=========

.. toctree::
   :maxdepth: 2



Depth First Search
------------------
.. automodule:: networkx.algorithms.traversal.depth_first_search
.. currentmodule:: networkx

.. autosummary::
   :toctree: generated/

   dfs_preorder
   dfs_postorder
   dfs_predecessor
   dfs_successor
   dfs_tree
